.. module:: hubugs

API documentation
=================

.. note::

   The documentation in this section is aimed at people wishing to contribute
   to :mod:`hubugs`, and can be skipped if you are simply using the tool from
   the command line.

.. toctree::
   :maxdepth: 2

   commandline
   models
   template
   utils
   errors
